Module access_api

Module access_api 

Enums

AccessChangePasswordError
struct for typed errors of method access_change_password
AccessGetAccessError
struct for typed errors of method access_get_access
AccessPermissionsError
struct for typed errors of method access_permissions
AccessVerifyVncTicketError
struct for typed errors of method access_verify_vnc_ticket

Functions

access_change_password
Change user password. Permissions: Each user is allowed to change their own password. A user can change the password of another user if they have ‘Realm.AllocateUser’ (on the realm of user ) and ‘User.Modify’ permission on /access/groups/ on a group where user is member of. For the PAM realm, a password change does not take effect cluster-wide, but only applies to the local node.
access_get_access
Directory index.
access_permissions
Retrieve effective permissions of given user/token. Permissions: Each user/token is allowed to dump their own permissions (or that of owned tokens). A user can dump the permissions of another user or their tokens if they have ‘Sys.Audit’ permission on /access.
access_verify_vnc_ticket
verify VNC authentication ticket. Permissions: You need to pass valid credientials.