Module access_users_api

Module access_users_api 

Enums

AccessUsersCreateUserError
struct for typed errors of method access_users_create_user
AccessUsersDeleteUserError
struct for typed errors of method access_users_delete_user
AccessUsersGenerateTokenError
struct for typed errors of method access_users_generate_token
AccessUsersGetUsersError
struct for typed errors of method access_users_get_users
AccessUsersReadTokenError
struct for typed errors of method access_users_read_token
AccessUsersReadUserError
struct for typed errors of method access_users_read_user
AccessUsersReadUserTfaTypeError
struct for typed errors of method access_users_read_user_tfa_type
AccessUsersRemoveTokenError
struct for typed errors of method access_users_remove_token
AccessUsersTokenIndexError
struct for typed errors of method access_users_token_index
AccessUsersUnlockTfaError
struct for typed errors of method access_users_unlock_tfa
AccessUsersUpdateTokenInfoError
struct for typed errors of method access_users_update_token_info
AccessUsersUpdateUserError
struct for typed errors of method access_users_update_user

Functions

access_users_create_user
Create new user. Permissions: You need ‘Realm.AllocateUser’ on ‘/access/realm/’ on the realm of user , and ‘User.Modify’ permissions to ‘/access/groups/’ for any group specified (or ‘User.Modify’ on ‘/access/groups’ if you pass no groups.
access_users_delete_user
Delete user.
access_users_generate_token
Generate a new API token for a specific user. NOTE: returns API token value, which needs to be stored as it cannot be retrieved afterwards!
access_users_get_users
User index. Permissions: The returned list is restricted to users where you have ‘User.Modify’ or ‘Sys.Audit’ permissions on ‘/access/groups’ or on a group the user belongs too. But it always includes the current (authenticated) user.
access_users_read_token
Get specific API token information.
access_users_read_user
Get user configuration.
access_users_read_user_tfa_type
Get user TFA types (Personal and Realm).
access_users_remove_token
Remove API token for a specific user.
access_users_token_index
Get user API tokens.
access_users_unlock_tfa
Unlock a user’s TFA authentication.
access_users_update_token_info
Update API token for a specific user. NOTE: when ‘regenerate’ is set, the returned token value needs to be stored as it cannot be retrieved afterwards!
access_users_update_user
Update user configuration.