Module cluster_notifications_api

Module cluster_notifications_api 

Enums

ClusterNotificationsCreateGotifyEndpointError
struct for typed errors of method cluster_notifications_create_gotify_endpoint
ClusterNotificationsCreateMatcherError
struct for typed errors of method cluster_notifications_create_matcher
ClusterNotificationsCreateSendmailEndpointError
struct for typed errors of method cluster_notifications_create_sendmail_endpoint
ClusterNotificationsCreateSmtpEndpointError
struct for typed errors of method cluster_notifications_create_smtp_endpoint
ClusterNotificationsCreateWebhookEndpointError
struct for typed errors of method cluster_notifications_create_webhook_endpoint
ClusterNotificationsDeleteGotifyEndpointError
struct for typed errors of method cluster_notifications_delete_gotify_endpoint
ClusterNotificationsDeleteMatcherError
struct for typed errors of method cluster_notifications_delete_matcher
ClusterNotificationsDeleteSendmailEndpointError
struct for typed errors of method cluster_notifications_delete_sendmail_endpoint
ClusterNotificationsDeleteSmtpEndpointError
struct for typed errors of method cluster_notifications_delete_smtp_endpoint
ClusterNotificationsDeleteWebhookEndpointError
struct for typed errors of method cluster_notifications_delete_webhook_endpoint
ClusterNotificationsEndpointsIndexError
struct for typed errors of method cluster_notifications_endpoints_index
ClusterNotificationsGetAllTargetsError
struct for typed errors of method cluster_notifications_get_all_targets
ClusterNotificationsGetGotifyEndpointError
struct for typed errors of method cluster_notifications_get_gotify_endpoint
ClusterNotificationsGetGotifyEndpointsError
struct for typed errors of method cluster_notifications_get_gotify_endpoints
ClusterNotificationsGetMatcherError
struct for typed errors of method cluster_notifications_get_matcher
ClusterNotificationsGetMatcherFieldValuesError
struct for typed errors of method cluster_notifications_get_matcher_field_values
ClusterNotificationsGetMatcherFieldsError
struct for typed errors of method cluster_notifications_get_matcher_fields
ClusterNotificationsGetMatchersError
struct for typed errors of method cluster_notifications_get_matchers
ClusterNotificationsGetNotificationsError
struct for typed errors of method cluster_notifications_get_notifications
ClusterNotificationsGetSendmailEndpointError
struct for typed errors of method cluster_notifications_get_sendmail_endpoint
ClusterNotificationsGetSendmailEndpointsError
struct for typed errors of method cluster_notifications_get_sendmail_endpoints
ClusterNotificationsGetSmtpEndpointError
struct for typed errors of method cluster_notifications_get_smtp_endpoint
ClusterNotificationsGetSmtpEndpointsError
struct for typed errors of method cluster_notifications_get_smtp_endpoints
ClusterNotificationsGetWebhookEndpointError
struct for typed errors of method cluster_notifications_get_webhook_endpoint
ClusterNotificationsGetWebhookEndpointsError
struct for typed errors of method cluster_notifications_get_webhook_endpoints
ClusterNotificationsTestTargetError
struct for typed errors of method cluster_notifications_test_target
ClusterNotificationsUpdateGotifyEndpointError
struct for typed errors of method cluster_notifications_update_gotify_endpoint
ClusterNotificationsUpdateMatcherError
struct for typed errors of method cluster_notifications_update_matcher
ClusterNotificationsUpdateSendmailEndpointError
struct for typed errors of method cluster_notifications_update_sendmail_endpoint
ClusterNotificationsUpdateSmtpEndpointError
struct for typed errors of method cluster_notifications_update_smtp_endpoint
ClusterNotificationsUpdateWebhookEndpointError
struct for typed errors of method cluster_notifications_update_webhook_endpoint

Functions

cluster_notifications_create_gotify_endpoint
Create a new gotify endpoint
cluster_notifications_create_matcher
Create a new matcher
cluster_notifications_create_sendmail_endpoint
Create a new sendmail endpoint
cluster_notifications_create_smtp_endpoint
Create a new smtp endpoint
cluster_notifications_create_webhook_endpoint
Create a new webhook endpoint
cluster_notifications_delete_gotify_endpoint
Remove gotify endpoint
cluster_notifications_delete_matcher
Remove matcher
cluster_notifications_delete_sendmail_endpoint
Remove sendmail endpoint
cluster_notifications_delete_smtp_endpoint
Remove smtp endpoint
cluster_notifications_delete_webhook_endpoint
Remove webhook endpoint
cluster_notifications_endpoints_index
Index for all available endpoint types.
cluster_notifications_get_all_targets
Returns a list of all entities that can be used as notification targets.
cluster_notifications_get_gotify_endpoint
Return a specific gotify endpoint
cluster_notifications_get_gotify_endpoints
Returns a list of all gotify endpoints
cluster_notifications_get_matcher
Return a specific matcher
cluster_notifications_get_matcher_field_values
Returns known notification metadata fields and their known values
cluster_notifications_get_matcher_fields
Returns known notification metadata fields
cluster_notifications_get_matchers
Returns a list of all matchers
cluster_notifications_get_notifications
Index for notification-related API endpoints.
cluster_notifications_get_sendmail_endpoint
Return a specific sendmail endpoint
cluster_notifications_get_sendmail_endpoints
Returns a list of all sendmail endpoints
cluster_notifications_get_smtp_endpoint
Return a specific smtp endpoint
cluster_notifications_get_smtp_endpoints
Returns a list of all smtp endpoints
cluster_notifications_get_webhook_endpoint
Return a specific webhook endpoint
cluster_notifications_get_webhook_endpoints
Returns a list of all webhook endpoints
cluster_notifications_test_target
Send a test notification to a provided target.
cluster_notifications_update_gotify_endpoint
Update existing gotify endpoint
cluster_notifications_update_matcher
Update existing matcher
cluster_notifications_update_sendmail_endpoint
Update existing sendmail endpoint
cluster_notifications_update_smtp_endpoint
Update existing smtp endpoint
cluster_notifications_update_webhook_endpoint
Update existing webhook endpoint