Module nodes_storage_api

Module nodes_storage_api 

Enums

NodesStorageCopyError
struct for typed errors of method nodes_storage_copy
NodesStorageCreateContentError
struct for typed errors of method nodes_storage_create_content
NodesStorageDeleteContentError
struct for typed errors of method nodes_storage_delete_content
NodesStorageDeletePrunebackupsError
struct for typed errors of method nodes_storage_delete_prunebackups
NodesStorageDiridxError
struct for typed errors of method nodes_storage_diridx
NodesStorageDownloadError
struct for typed errors of method nodes_storage_download
NodesStorageDownloadUrlError
struct for typed errors of method nodes_storage_download_url
NodesStorageDryrunError
struct for typed errors of method nodes_storage_dryrun
NodesStorageGetContentError
struct for typed errors of method nodes_storage_get_content
NodesStorageGetImportMetadataError
struct for typed errors of method nodes_storage_get_import_metadata
NodesStorageGetListError
struct for typed errors of method nodes_storage_get_list
NodesStorageGetStorageError
struct for typed errors of method nodes_storage_get_storage
NodesStorageIdentityError
struct for typed errors of method nodes_storage_identity
NodesStorageInfoError
struct for typed errors of method nodes_storage_info
NodesStorageOciRegistryPullError
struct for typed errors of method nodes_storage_oci_registry_pull
NodesStorageReadStatusError
struct for typed errors of method nodes_storage_read_status
NodesStorageRrdError
struct for typed errors of method nodes_storage_rrd
NodesStorageRrddataError
struct for typed errors of method nodes_storage_rrddata
NodesStorageUpdateattributesError
struct for typed errors of method nodes_storage_updateattributes
NodesStorageUploadError
struct for typed errors of method nodes_storage_upload

Functions

nodes_storage_copy
Copy a volume. This is experimental code - do not use.
nodes_storage_create_content
Allocate disk images.
nodes_storage_delete_content
Delete volume Permissions: You need ‘Datastore.Allocate’ privilege on the storage (or ‘Datastore.AllocateSpace’ for backup volumes if you have VM.Backup privilege on the VM).
nodes_storage_delete_prunebackups
Prune backups. Only those using the standard naming scheme are considered. Permissions: You need the ‘Datastore.Allocate’ privilege on the storage (or if a VM ID is specified, ‘Datastore.AllocateSpace’ and ‘VM.Backup’ for the VM).
nodes_storage_diridx
nodes_storage_download
Extract a file or directory (as zip archive) from a PBS backup. Permissions: You need read access for the volume.
nodes_storage_download_url
Download templates, ISO images, OVAs and VM images by using an URL. Permissions: Requires allocation access on the storage and as this allows one to probe the (local!) host network indirectly it also requires one of Sys.Modify on / (for backwards compatibility) or the newer Sys.AccessNetwork privilege on the node.
nodes_storage_dryrun
Get prune information for backups. NOTE: this is only a preview and might not be what a subsequent prune call does if backups are removed/added in the meantime.
nodes_storage_get_content
List storage content.
nodes_storage_get_import_metadata
Get the base parameters for creating a guest which imports data from a foreign importable guest, like an ESXi VM Permissions: You need read access for the volume.
nodes_storage_get_list
List files and directories for single file restore under the given path. Permissions: You need read access for the volume.
nodes_storage_get_storage
Get status for all datastores. Permissions: Only list entries where you have ‘Datastore.Audit’ or ‘Datastore.AllocateSpace’ permissions on ‘/storage/
nodes_storage_identity
Return identity information for this storage instance.
nodes_storage_info
Get volume attributes Permissions: You need read access for the volume.
nodes_storage_oci_registry_pull
Pull an OCI image from a registry.
nodes_storage_read_status
Read storage status.
nodes_storage_rrd
Read storage RRD statistics (returns PNG).
nodes_storage_rrddata
Read storage RRD statistics.
nodes_storage_updateattributes
Update volume attributes Permissions: You need read access for the volume.
nodes_storage_upload
Upload templates, ISO images, OVAs and VM images.