Module nodes_tasks_api

Module nodes_tasks_api 

Enums

NodesTasksNodeTasksError
struct for typed errors of method nodes_tasks_node_tasks
NodesTasksReadTaskLogError
struct for typed errors of method nodes_tasks_read_task_log
NodesTasksReadTaskStatusError
struct for typed errors of method nodes_tasks_read_task_status
NodesTasksStopTaskError
struct for typed errors of method nodes_tasks_stop_task
NodesTasksUpidIndexError
struct for typed errors of method nodes_tasks_upid_index

Functions

nodes_tasks_node_tasks
Read task list for one node (finished tasks). Permissions: List task associated with the current user, or all task the user has ‘Sys.Audit’ permissions on /nodes/ (the the task runs on).
nodes_tasks_read_task_log
Read task log. Permissions: The user needs ‘Sys.Audit’ permissions on ‘/nodes/’ if they aren’t the owner of the task.
nodes_tasks_read_task_status
Read task status. Permissions: The user needs ‘Sys.Audit’ permissions on ‘/nodes/’ if they are not the owner of the task.
nodes_tasks_stop_task
Stop a task. Permissions: The user needs ‘Sys.Modify’ permissions on ‘/nodes/’ if they aren’t the owner of the task.
nodes_tasks_upid_index