pub async fn version_version(
configuration: &Configuration,
) -> Result<VersionVersionResponse, Error<VersionVersionError>>Expand description
API version details, including some parts of the global datacenter config.
pub async fn version_version(
configuration: &Configuration,
) -> Result<VersionVersionResponse, Error<VersionVersionError>>API version details, including some parts of the global datacenter config.