pub struct AccessTfaAddTfaEntryResponseData {
pub challenge: Option<String>,
pub id: String,
pub recovery: Option<Vec<String>>,
}Fields
challenge: Option<String>When adding u2f entries, this contains a challenge the user must respond to in order to finish the registration.
id: StringThe id of a newly added TFA entry.
recovery: Option<Vec<String>>When adding recovery codes, this contains the list of codes to be displayed to the user
Implementations
Sourceimpl AccessTfaAddTfaEntryResponseData
impl AccessTfaAddTfaEntryResponseData
pub fn new(id: String) -> AccessTfaAddTfaEntryResponseData