pub struct ClusterBackupGetBackupResponseDataInner {Show 37 fields
pub all: Option<PveBoolean>,
pub bwlimit: Option<i64>,
pub comment: Option<String>,
pub compress: Option<PveCompressEnum>,
pub dumpdir: Option<String>,
pub enabled: Option<PveBoolean>,
pub exclude: Option<String>,
pub exclude_path: Option<Vec<String>>,
pub fleecing: Option<Box<ClusterBackupGetBackupResponseDataInnerFleecing>>,
pub id: String,
pub ionice: Option<i32>,
pub lockwait: Option<i64>,
pub mailnotification: Option<PveMailnotificationEnum>,
pub mailto: Option<String>,
pub mode: Option<PveClusterBackupModeEnum>,
pub next_run: Option<i64>,
pub node: Option<String>,
pub notes_template: Option<String>,
pub notification_mode: Option<PveNotificationModeEnum>,
pub pbs_change_detection_mode: Option<PvePbsChangeDetectionModeEnum>,
pub performance: Option<Box<ClusterBackupGetBackupResponseDataInnerPerformance>>,
pub pigz: Option<i64>,
pub pool: Option<String>,
pub protected: Option<PveBoolean>,
pub prune_backups: Option<Box<ClusterBackupGetBackupResponseDataInnerPruneBackups>>,
pub quiet: Option<PveBoolean>,
pub remove: Option<PveBoolean>,
pub repeat_missed: Option<PveBoolean>,
pub schedule: Option<String>,
pub script: Option<String>,
pub stdexcludes: Option<PveBoolean>,
pub stop: Option<PveBoolean>,
pub stopwait: Option<i64>,
pub storage: Option<String>,
pub tmpdir: Option<String>,
pub vmid: Option<String>,
pub zstd: Option<i64>,
}Fields
all: Option<PveBoolean>Backup all known guest systems on this host.
bwlimit: Option<i64>Limit I/O bandwidth (in KiB/s).
comment: Option<String>Description for the Job.
compress: Option<PveCompressEnum>Compress dump file.
dumpdir: Option<String>Store resulting files to specified directory.
enabled: Option<PveBoolean>Enable or disable the job.
exclude: Option<String>Exclude specified guest systems (assumes –all)
exclude_path: Option<Vec<String>>Exclude certain files/directories (shell globs). Paths starting with ‘/’ are anchored to the container’s root, other paths match relative to each subdirectory.
fleecing: Option<Box<ClusterBackupGetBackupResponseDataInnerFleecing>>id: StringThe job ID.
ionice: Option<i32>Set IO priority when using the BFQ scheduler. For snapshot and suspend mode backups of VMs, this only affects the compressor. A value of 8 means the idle priority is used, otherwise the best-effort priority is used with the specified value.
lockwait: Option<i64>Maximal time to wait for the global lock (minutes).
mailnotification: Option<PveMailnotificationEnum>Deprecated: use notification targets/matchers instead. Specify when to send a notification mail
mailto: Option<String>Deprecated: Use notification targets/matchers instead. Comma-separated list of email addresses or users that should receive email notifications.
mode: Option<PveClusterBackupModeEnum>Backup mode.
next_run: Option<i64>UNIX timestamp when this backup job will be executed next
node: Option<String>Only run if executed on this node.
notes_template: Option<String>Template string for generating notes for the backup(s). It can contain variables which will be replaced by their values. Currently supported are {{cluster}}, {{guestname}}, {{node}}, and {{vmid}}, but more might be added in the future. Needs to be a single line, newline and backslash need to be escaped as ‘\n’ and ‘\\’ respectively.
notification_mode: Option<PveNotificationModeEnum>Determine which notification system to use. If set to ‘legacy-sendmail’, vzdump will consider the mailto/mailnotification parameters and send emails to the specified address(es) via the ‘sendmail’ command. If set to ‘notification-system’, a notification will be sent via PVE’s notification system, and the mailto and mailnotification will be ignored. If set to ‘auto’ (default setting), an email will be sent if mailto is set, and the notification system will be used if not.
pbs_change_detection_mode: Option<PvePbsChangeDetectionModeEnum>PBS mode used to detect file changes and switch encoding format for container backups.
performance: Option<Box<ClusterBackupGetBackupResponseDataInnerPerformance>>pigz: Option<i64>Use pigz instead of gzip when N>0. N=1 uses half of cores, N>1 uses N as thread count.
pool: Option<String>Backup all known guest systems included in the specified pool.
protected: Option<PveBoolean>If true, mark backup(s) as protected.
prune_backups: Option<Box<ClusterBackupGetBackupResponseDataInnerPruneBackups>>quiet: Option<PveBoolean>Be quiet.
remove: Option<PveBoolean>Prune older backups according to ‘prune-backups’.
repeat_missed: Option<PveBoolean>If true, the job will be run as soon as possible if it was missed while the scheduler was not running.
schedule: Option<String>Backup schedule. The format is a subset of systemd calendar events.
script: Option<String>Use specified hook script.
stdexcludes: Option<PveBoolean>Exclude temporary files and logs.
stop: Option<PveBoolean>Stop running backup jobs on this host.
stopwait: Option<i64>Maximal time to wait until a guest system is stopped (minutes).
storage: Option<String>Store resulting file to this storage.
tmpdir: Option<String>Store temporary files to specified directory.
vmid: Option<String>The ID of the guest system you want to backup.
zstd: Option<i64>Zstd threads. N=0 uses half of the available cores, if N is set to a value bigger than 0, N is used as thread count.
Implementations