pub struct ClusterCephMetadataResponseData {
pub mds: HashMap<String, ClusterCephMetadataResponseDataMdsValue>,
pub mgr: HashMap<String, ClusterCephMetadataResponseDataMgrValue>,
pub mon: HashMap<String, ClusterCephMetadataResponseDataMonValue>,
pub node: HashMap<String, ClusterCephMetadataResponseDataNodeValue>,
pub osd: Vec<ClusterCephMetadataResponseDataOsdInner>,
}Fields
mds: HashMap<String, ClusterCephMetadataResponseDataMdsValue>Metadata servers configured in the cluster and their properties, keyed by ‘
mgr: HashMap<String, ClusterCephMetadataResponseDataMgrValue>Managers configured in the cluster and their properties, keyed by ‘
mon: HashMap<String, ClusterCephMetadataResponseDataMonValue>Monitors configured in the cluster and their properties, keyed by ‘
node: HashMap<String, ClusterCephMetadataResponseDataNodeValue>Ceph version installed on the nodes, keyed by node name.
osd: Vec<ClusterCephMetadataResponseDataOsdInner>OSDs configured in the cluster and their properties.
Implementations
Sourceimpl ClusterCephMetadataResponseData
impl ClusterCephMetadataResponseData
pub fn new( mds: HashMap<String, ClusterCephMetadataResponseDataMdsValue>, mgr: HashMap<String, ClusterCephMetadataResponseDataMgrValue>, mon: HashMap<String, ClusterCephMetadataResponseDataMonValue>, node: HashMap<String, ClusterCephMetadataResponseDataNodeValue>, osd: Vec<ClusterCephMetadataResponseDataOsdInner>, ) -> ClusterCephMetadataResponseData