pub struct ClusterGetStatusResponseDataInner {
pub id: String,
pub ip: Option<String>,
pub level: Option<String>,
pub local: Option<PveBoolean>,
pub name: String,
pub nodeid: Option<i64>,
pub nodes: Option<i64>,
pub online: Option<PveBoolean>,
pub quorate: Option<PveBoolean>,
pub type: PveClusterTypeEnum3,
pub version: Option<i64>,
}Fields
id: Stringip: Option<String>[node] IP of the resolved nodename.
level: Option<String>[node] Proxmox VE Subscription level, indicates if eligible for enterprise support as well as access to the stable Proxmox VE Enterprise Repository.
local: Option<PveBoolean>[node] Indicates if this is the responding node.
name: Stringnodeid: Option<i64>[node] ID of the node from the corosync configuration.
nodes: Option<i64>[cluster] Nodes count, including offline nodes.
online: Option<PveBoolean>[node] Indicates if the node is online or offline.
quorate: Option<PveBoolean>[cluster] Indicates if there is a majority of nodes online to make decisions
type: PveClusterTypeEnum3Indicates the type, either cluster or node. The type defines the object properties e.g. quorate available for type cluster.
version: Option<i64>[cluster] Current version of the corosync configuration file.
Implementations
Sourceimpl ClusterGetStatusResponseDataInner
impl ClusterGetStatusResponseDataInner
pub fn new( id: String, name: String, type: PveClusterTypeEnum3, ) -> ClusterGetStatusResponseDataInner