ClusterHaCreateResourcesRequest

Struct ClusterHaCreateResourcesRequest 

pub struct ClusterHaCreateResourcesRequest {
    pub auto_rebalance: Option<PveBoolean>,
    pub comment: Option<String>,
    pub failback: Option<PveBoolean>,
    pub group: Option<String>,
    pub max_relocate: Option<i64>,
    pub max_restart: Option<i64>,
    pub sid: String,
    pub state: Option<PveStateEnum>,
    pub type: Option<PveClusterHaTypeTypeEnum>,
}

Fields

auto_rebalance: Option<PveBoolean>

HA resource may be migrated during automatic rebalancing

comment: Option<String>

Description.

failback: Option<PveBoolean>

Automatically migrate HA resource to the node with the highest priority according to their node affinity rules, if a node with a higher priority than the current node comes online.

group: Option<String>

The HA group identifier.

max_relocate: Option<i64>

Maximal number of resource relocate tries when a resource fails to start.

max_restart: Option<i64>

Maximal number of tries to restart the resource on a node after its start failed. When reached, the HA manager will try to relocate the resource to an eligible node.

sid: String

HA resource ID. This consists of a resource type followed by a resource specific name, separated with colon (example: vm:100 / ct:100). For virtual machines and containers, you can simply use the VM or CT id as a shortcut (example: 100).

state: Option<PveStateEnum>

Requested resource state. The CRM reads this state and acts accordingly. Please note that enabled is just an alias for started. started;; The CRM tries to start the resource. Service state is set to started after successful start. On node failures, or when start fails, it tries to recover the resource. If everything fails, service state it set to error. stopped;; The CRM tries to keep the resource in stopped state, but it still tries to relocate the resources on node failures. disabled;; The CRM tries to put the resource in stopped state, but does not try to relocate the resources on node failures. The main purpose of this state is error recovery, because it is the only way to move a resource out of the error state. ignored;; The resource gets removed from the manager status and so the CRM and the LRM do not touch the resource anymore. All {pve} API calls affecting this resource will be executed, directly bypassing the HA stack. CRM commands will be thrown away while the resource is in this state. The resource will not get relocated on node failures.

type: Option<PveClusterHaTypeTypeEnum>

Resource type.

Implementations