ClusterHaReadGetResourcesResponseData

Struct ClusterHaReadGetResourcesResponseData 

pub struct ClusterHaReadGetResourcesResponseData {
    pub auto_rebalance: Option<PveBoolean>,
    pub comment: Option<String>,
    pub digest: String,
    pub failback: Option<PveBoolean>,
    pub group: Option<String>,
    pub max_relocate: Option<i64>,
    pub max_restart: Option<i64>,
    pub sid: String,
    pub state: Option<PveStateEnum>,
    pub type: String,
}

Fields

auto_rebalance: Option<PveBoolean>

HA resource may be migrated during automatic rebalancing.

comment: Option<String>

Description.

digest: String

Can be used to prevent concurrent modifications.

failback: Option<PveBoolean>

The HA resource is automatically migrated to the node with the highest priority according to their node affinity rule, if a node with a higher priority than the current node comes online.

group: Option<String>

The HA group identifier.

max_relocate: Option<i64>

Maximal number of service relocate tries when a service fails to start.

max_restart: Option<i64>

Maximal number of tries to restart the service on a node after its start failed.

sid: String

HA resource ID. This consists of a resource type followed by a resource specific name, separated with colon (example: vm:100 / ct:100). For virtual machines and containers, you can simply use the VM or CT id as a shortcut (example: 100).

state: Option<PveStateEnum>

Requested resource state.

type: String

The type of the resources.

Implementations