pub struct ClusterHaRelocateResponseData {
pub blocking_resources: Option<Vec<ClusterHaRelocateResponseDataBlockingResourcesInner>>,
pub comigrated_resources: Option<Vec<String>>,
pub requested_node: String,
pub sid: String,
}Fields
blocking_resources: Option<Vec<ClusterHaRelocateResponseDataBlockingResourcesInner>>HA resources, which are blocking the given HA resource from being relocated to the requested target node.
comigrated_resources: Option<Vec<String>>HA resources, which are relocated to the same requested target node as the given HA resource, because these are in positive affinity with the HA resource.
requested_node: StringNode, which was requested to be relocated to.
sid: StringHA resource, which is requested to be relocated.
Implementations
Sourceimpl ClusterHaRelocateResponseData
impl ClusterHaRelocateResponseData
pub fn new(requested_node: String, sid: String) -> ClusterHaRelocateResponseData