pub struct ClusterHaStatusResponseDataInner {Show 16 fields
pub armed_state: Option<PveClusterHaArmedStateEnum>,
pub auto_rebalance: Option<PveBoolean>,
pub crm_state: Option<String>,
pub failback: Option<PveBoolean>,
pub id: String,
pub max_relocate: Option<i64>,
pub max_restart: Option<i64>,
pub node: String,
pub quorate: Option<PveBoolean>,
pub request_state: Option<String>,
pub resource_mode: Option<PveResourceModeEnum>,
pub sid: Option<String>,
pub state: Option<String>,
pub status: String,
pub timestamp: Option<i64>,
pub type: Type,
}Fields
armed_state: Option<PveClusterHaArmedStateEnum>For type ‘fencing’. Whether HA is armed, on standby, disarming or disarmed.
auto_rebalance: Option<PveBoolean>HA resource may be migrated during automatic rebalancing.
crm_state: Option<String>For type ‘service’. Service state as seen by the CRM.
failback: Option<PveBoolean>The HA resource is automatically migrated to the node with the highest priority according to their node affinity rule, if a node with a higher priority than the current node comes online.
id: StringStatus entry ID (quorum, master, lrm:
max_relocate: Option<i64>For type ‘service’.
max_restart: Option<i64>For type ‘service’.
node: StringNode associated to status entry.
quorate: Option<PveBoolean>For type ‘quorum’. Whether the cluster is quorate or not.
request_state: Option<String>For type ‘service’. Requested service state.
resource_mode: Option<PveResourceModeEnum>For type ‘fencing’. How resources are handled while disarmed.
sid: Option<String>For type ‘service’. Service ID.
state: Option<String>For type ‘service’. Verbose service state.
status: StringStatus of the entry (value depends on type).
timestamp: Option<i64>For type ‘lrm’,‘master’. Timestamp of the status information.
type: TypeType of status entry.
Implementations