pub struct ClusterNotificationsGetSmtpEndpointsResponseDataInner {
pub author: Option<String>,
pub comment: Option<String>,
pub disable: Option<PveBoolean>,
pub from_address: String,
pub mailto: Option<Vec<String>>,
pub mailto_user: Option<Vec<String>>,
pub mode: Option<PveClusterNotificationsModeEnum>,
pub name: String,
pub origin: PveOriginEnum,
pub port: Option<i64>,
pub server: String,
pub username: Option<String>,
}Fields
Author of the mail. Defaults to ‘Proxmox VE’.
comment: Option<String>Comment
disable: Option<PveBoolean>Disable this target
from_address: StringFrom address for the mail
mailto: Option<Vec<String>>List of email recipients
mailto_user: Option<Vec<String>>List of users
mode: Option<PveClusterNotificationsModeEnum>Determine which encryption method shall be used for the connection.
name: StringThe name of the endpoint.
origin: PveOriginEnumShow if this entry was created by a user or was built-in
port: Option<i64>The port to be used. Defaults to 465 for TLS based connections, 587 for STARTTLS based connections and port 25 for insecure plain-text connections.
server: StringThe address of the SMTP server.
username: Option<String>Username for SMTP authentication
Implementations
Sourceimpl ClusterNotificationsGetSmtpEndpointsResponseDataInner
impl ClusterNotificationsGetSmtpEndpointsResponseDataInner
pub fn new( from_address: String, name: String, origin: PveOriginEnum, server: String, ) -> ClusterNotificationsGetSmtpEndpointsResponseDataInner