pub struct ClusterNotificationsGetWebhookEndpointResponseData {
pub body: Option<String>,
pub comment: Option<String>,
pub digest: Option<String>,
pub disable: Option<PveBoolean>,
pub header: Option<Vec<String>>,
pub method: PveMethodEnum,
pub name: String,
pub secret: Option<Vec<String>>,
pub url: String,
}Fields
body: Option<String>HTTP body, base64 encoded
comment: Option<String>Comment
digest: Option<String>Prevent changes if current configuration file has a different digest. This can be used to prevent concurrent modifications.
disable: Option<PveBoolean>Disable this target
header: Option<Vec<String>>HTTP headers to set. These have to be formatted as a property string in the format name=
method: PveMethodEnumHTTP method
name: StringThe name of the endpoint.
secret: Option<Vec<String>>Secrets to set. These have to be formatted as a property string in the format name=
url: StringServer URL
Implementations
Sourceimpl ClusterNotificationsGetWebhookEndpointResponseData
impl ClusterNotificationsGetWebhookEndpointResponseData
pub fn new( method: PveMethodEnum, name: String, url: String, ) -> ClusterNotificationsGetWebhookEndpointResponseData