pub struct ClusterNotificationsGetWebhookEndpointsResponseDataInner {
pub body: Option<String>,
pub comment: Option<String>,
pub disable: Option<PveBoolean>,
pub header: Option<Vec<String>>,
pub method: PveMethodEnum,
pub name: String,
pub origin: PveOriginEnum,
pub secret: Option<Vec<String>>,
pub url: String,
}Fields
body: Option<String>HTTP body, base64 encoded
comment: Option<String>Comment
disable: Option<PveBoolean>Disable this target
header: Option<Vec<String>>HTTP headers to set. These have to be formatted as a property string in the format name=
method: PveMethodEnumHTTP method
name: StringThe name of the endpoint.
origin: PveOriginEnumShow if this entry was created by a user or was built-in
secret: Option<Vec<String>>Secrets to set. These have to be formatted as a property string in the format name=
url: StringServer URL
Implementations
Sourceimpl ClusterNotificationsGetWebhookEndpointsResponseDataInner
impl ClusterNotificationsGetWebhookEndpointsResponseDataInner
pub fn new( method: PveMethodEnum, name: String, origin: PveOriginEnum, url: String, ) -> ClusterNotificationsGetWebhookEndpointsResponseDataInner