pub struct ClusterNotificationsUpdateSmtpEndpointRequest {Show 13 fields
pub author: Option<String>,
pub comment: Option<String>,
pub delete: Option<Vec<String>>,
pub digest: Option<String>,
pub disable: Option<PveBoolean>,
pub from_address: Option<String>,
pub mailto: Option<Vec<String>>,
pub mailto_user: Option<Vec<String>>,
pub mode: Option<PveClusterNotificationsModeEnum>,
pub password: Option<String>,
pub port: Option<i64>,
pub server: Option<String>,
pub username: Option<String>,
}Fields
Author of the mail. Defaults to ‘Proxmox VE’.
comment: Option<String>Comment
delete: Option<Vec<String>>A list of settings you want to delete.
digest: Option<String>Prevent changes if current configuration file has a different digest. This can be used to prevent concurrent modifications.
disable: Option<PveBoolean>Disable this target
from_address: Option<String>From address for the mail
mailto: Option<Vec<String>>List of email recipients
mailto_user: Option<Vec<String>>List of users
mode: Option<PveClusterNotificationsModeEnum>Determine which encryption method shall be used for the connection.
password: Option<String>Password for SMTP authentication
port: Option<i64>The port to be used. Defaults to 465 for TLS based connections, 587 for STARTTLS based connections and port 25 for insecure plain-text connections.
server: Option<String>The address of the SMTP server.
username: Option<String>Username for SMTP authentication
Implementations