pub struct ClusterNotificationsUpdateWebhookEndpointRequest {
pub body: Option<String>,
pub comment: Option<String>,
pub delete: Option<Vec<String>>,
pub digest: Option<String>,
pub disable: Option<PveBoolean>,
pub header: Option<Vec<String>>,
pub method: Option<PveMethodEnum>,
pub secret: Option<Vec<String>>,
pub url: Option<String>,
}Fields
body: Option<String>HTTP body, base64 encoded
comment: Option<String>Comment
delete: Option<Vec<String>>A list of settings you want to delete.
digest: Option<String>Prevent changes if current configuration file has a different digest. This can be used to prevent concurrent modifications.
disable: Option<PveBoolean>Disable this target
header: Option<Vec<String>>HTTP headers to set. These have to be formatted as a property string in the format name=
method: Option<PveMethodEnum>HTTP method
secret: Option<Vec<String>>Secrets to set. These have to be formatted as a property string in the format name=
url: Option<String>Server URL
Implementations