ClusterOptionsSetOptionsRequest

Struct ClusterOptionsSetOptionsRequest 

pub struct ClusterOptionsSetOptionsRequest {
Show 24 fields pub bwlimit: Option<Box<PveBwlimitField>>, pub consent_text: Option<String>, pub console: Option<PveConsoleEnum>, pub crs: Option<Box<PveCrsField>>, pub delete: Option<String>, pub description: Option<String>, pub email_from: Option<String>, pub fencing: Option<PveClusterOptionsFencingEnum>, pub ha: Option<Box<PveHaField>>, pub http_proxy: Option<String>, pub keyboard: Option<PveKeyboardEnum>, pub language: Option<PveClusterOptionsLanguageEnum>, pub location: Option<Box<PveLocationField>>, pub mac_prefix: Option<String>, pub max_workers: Option<i64>, pub migration: Option<Box<PveMigrationField>>, pub next_id: Option<Box<PveNextIdField>>, pub notify: Option<Box<PveNotifyField>>, pub registered_tags: Option<String>, pub replication: Option<Box<PveReplicationField>>, pub tag_style: Option<Box<PveTagStyleField>>, pub u2f: Option<Box<PveU2fField>>, pub user_tag_access: Option<Box<PveUserTagAccessField>>, pub webauthn: Option<Box<PveWebauthnField>>,
}

Fields

bwlimit: Option<Box<PveBwlimitField>>

Set I/O bandwidth limit for various operations (in KiB/s).

consent_text: Option<String>

Consent text that is displayed before logging in.

console: Option<PveConsoleEnum>

Select the default Console viewer. You can either use the builtin java applet (VNC; deprecated and maps to html5), an external virt-viewer comtatible application (SPICE), an HTML5 based vnc viewer (noVNC), or an HTML5 based console client (xtermjs). If the selected viewer is not available (e.g. SPICE not activated for the VM), the fallback is noVNC.

crs: Option<Box<PveCrsField>>

Cluster resource scheduling settings.

delete: Option<String>

A list of settings you want to delete.

description: Option<String>

Datacenter description. Shown in the web-interface datacenter notes panel. This is saved as comment inside the configuration file.

email_from: Option<String>

Specify email address to send notification from (default is root@$hostname)

fencing: Option<PveClusterOptionsFencingEnum>

Set the fencing mode of the HA cluster. Hardware mode needs a valid configuration of fence devices in /etc/pve/ha/fence.cfg. With both all two modes are used. WARNING: ‘hardware’ and ‘both’ are EXPERIMENTAL & WIP

ha: Option<Box<PveHaField>>

Cluster wide HA settings.

http_proxy: Option<String>

Specify external http proxy which is used for downloads (example: ‘http://username:password@host:port/’)

keyboard: Option<PveKeyboardEnum>

Default keybord layout for vnc server.

language: Option<PveClusterOptionsLanguageEnum>

Default GUI language.

location: Option<Box<PveLocationField>>

The location of the cluster.

mac_prefix: Option<String>

Prefix for the auto-generated MAC addresses of virtual guests. The default BC:24:11 is the Organizationally Unique Identifier (OUI) assigned by the IEEE to Proxmox Server Solutions GmbH for a MAC Address Block Large (MA-L). You’re allowed to use this in local networks, i.e., those not directly reachable by the public (e.g., in a LAN or NAT/Masquerading). Note that when you run multiple cluster that (partially) share the networks of their virtual guests, it’s highly recommended that you extend the default MAC prefix, or generate a custom (valid) one, to reduce the chance of MAC collisions. For example, add a separate extra hexadecimal to the Proxmox OUI for each cluster, like BC:24:11:0 for the first, BC:24:11:1 for the second, and so on. Alternatively, you can also separate the networks of the guests logically, e.g., by using VLANs. For publicly accessible guests it’s recommended that you get your own https://standards.ieee.org/products-programs/regauth/[OUI from the IEEE] registered or coordinate with your, or your hosting providers, network admins.

max_workers: Option<i64>

Defines how many workers (per node) are maximal started on actions like ‘stopall VMs’ or task from the ha-manager.

migration: Option<Box<PveMigrationField>>

For cluster wide migration settings.

next_id: Option<Box<PveNextIdField>>

Control the range for the free VMID auto-selection pool.

notify: Option<Box<PveNotifyField>>

Cluster-wide notification settings.

registered_tags: Option<String>

A list of tags that require a Sys.Modify on ‘/’ to set and delete. Tags set here that are also in ‘user-tag-access’ also require Sys.Modify.

replication: Option<Box<PveReplicationField>>

For cluster wide replication settings.

tag_style: Option<Box<PveTagStyleField>>

Tag style options.

u2f: Option<Box<PveU2fField>>

u2f

user_tag_access: Option<Box<PveUserTagAccessField>>

Privilege options for user-settable tags

webauthn: Option<Box<PveWebauthnField>>

webauthn configuration

Implementations