ClusterQemuCreateCustomCpuModelsRequest

Struct ClusterQemuCreateCustomCpuModelsRequest 

pub struct ClusterQemuCreateCustomCpuModelsRequest {
    pub cputype: String,
    pub flags: Option<String>,
    pub guest_phys_bits: Option<i32>,
    pub hidden: Option<PveBoolean>,
    pub hv_vendor_id: Option<String>,
    pub level: Option<i32>,
    pub phys_bits: Option<String>,
    pub reported_model: PveReportedModelEnum,
}

Fields

cputype: String

Name for the custom CPU model. The ‘custom-’ prefix is optional.

flags: Option<String>

List of additional CPU flags separated by ‘;’. Use ‘+FLAG’ to enable, ‘-FLAG’ to disable a flag. There is a special ‘nested-virt’ shorthand which controls nested virtualization for the current CPU (‘svm’ for AMD and ‘vmx’ for Intel). Custom CPU models can specify any flag supported by QEMU/KVM, VM-specific flags must be from the following set for security reasons: aes, amd-no-ssb, amd-ssbd, hv-evmcs, hv-tlbflush, ibpb, md-clear, nested-virt, pcid, pdpe1gb, spec-ctrl, ssbd, virt-ssbd

guest_phys_bits: Option<i32>

Number of physical address bits available to the guest.

hidden: Option<PveBoolean>

Do not identify as a KVM virtual machine. Only affects vCPUs with x86-64 architecture.

hv_vendor_id: Option<String>

The Hyper-V vendor ID. Some drivers or programs inside Windows guests need a specific ID.

level: Option<i32>

Maximum input value for the basic CPUID leaves the guest can query - that is the vendor (leaf 0), family/model/stepping and feature bits (leaf 1), cache and topology info (leaves 4 and B), and so on. Higher-numbered leaves are hidden. Setting ‘30’ is a common workaround for Hyper-V boot failures on Windows guests running on recent Intel hosts. Only applies when the vCPU architecture is x86_64.

phys_bits: Option<String>

The physical memory address bits that are reported to the guest OS. Should be smaller or equal to the host’s. Set to ‘host’ to use value from host CPU, but note that doing so will break live migration to CPUs with other values.

reported_model: PveReportedModelEnum

CPU model and vendor to report to the guest. Must be a QEMU/KVM supported model. Only valid for custom CPU model definitions, default models will always report themselves to the guest OS.

Implementations