pub struct ClusterReplicationUpdateReplicationRequest {
pub comment: Option<String>,
pub delete: Option<String>,
pub digest: Option<String>,
pub disable: Option<PveBoolean>,
pub rate: Option<f64>,
pub remove_job: Option<PveRemoveJobEnum>,
pub schedule: Option<String>,
pub source: Option<String>,
}Fields
comment: Option<String>Description.
delete: Option<String>A list of settings you want to delete.
digest: Option<String>Prevent changes if current configuration file has a different digest. This can be used to prevent concurrent modifications.
disable: Option<PveBoolean>Flag to disable/deactivate the entry.
rate: Option<f64>Rate limit in mbps (megabytes per second) as floating point number.
remove_job: Option<PveRemoveJobEnum>Mark the replication job for removal. The job will remove all local replication snapshots. When set to ‘full’, it also tries to remove replicated volumes on the target. The job then removes itself from the configuration file.
schedule: Option<String>Storage replication schedule. The format is a subset of systemd calendar events.
source: Option<String>For internal use, to detect if the guest was stolen.
Implementations