pub struct ClusterSdnGetControllersResponseDataInnerPending {Show 13 fields
pub asn: Option<i32>,
pub bgp_mode: Option<PveBgpModeEnum>,
pub bgp_multipath_as_relax: Option<PveBoolean>,
pub ebgp: Option<PveBoolean>,
pub ebgp_multihop: Option<i64>,
pub isis_domain: Option<String>,
pub isis_ifaces: Option<String>,
pub isis_net: Option<String>,
pub loopback: Option<String>,
pub node: Option<String>,
pub nodes: Option<String>,
pub peer_group_name: Option<String>,
pub peers: Option<String>,
}Expand description
ClusterSdnGetControllersResponseDataInnerPending : Changes that have not yet been applied to the running configuration.
Fields
asn: Option<i32>The local ASN of the controller. BGP & EVPN only.
bgp_mode: Option<PveBgpModeEnum>Whether to use eBGP or iBGP. Auto mode chooses depending on BGP controller or falls back to iBGP.
bgp_multipath_as_relax: Option<PveBoolean>Consider different AS paths of equal length for multipath computation. BGP only.
ebgp: Option<PveBoolean>Enable eBGP (remote-as external). BGP only.
ebgp_multihop: Option<i64>Set maximum amount of hops for eBGP peers. Needs ebgp set to 1. BGP only.
isis_domain: Option<String>Name of the IS-IS domain. IS-IS only.
isis_ifaces: Option<String>Comma-separated list of interfaces where IS-IS should be active. IS-IS only.
isis_net: Option<String>Network Entity title for this node in the IS-IS network. IS-IS only.
loopback: Option<String>Name of the loopback/dummy interface that provides the Router-IP. BGP only.
node: Option<String>Node(s) where this controller is active.
nodes: Option<String>List of cluster node names.
peer_group_name: Option<String>Name of the peer group for this EVPN controller
peers: Option<String>Comma-separated list of the peers IP addresses.
Implementations
Sourceimpl ClusterSdnGetControllersResponseDataInnerPending
impl ClusterSdnGetControllersResponseDataInnerPending
Sourcepub fn new() -> ClusterSdnGetControllersResponseDataInnerPending
pub fn new() -> ClusterSdnGetControllersResponseDataInnerPending
Changes that have not yet been applied to the running configuration.