pub struct ClusterSdnUpdateControllersRequest {Show 19 fields
pub asn: Option<i32>,
pub bgp_mode: Option<PveBgpModeEnum>,
pub bgp_multipath_as_path_relax: Option<PveBoolean>,
pub delete: Option<String>,
pub digest: Option<String>,
pub ebgp: Option<PveBoolean>,
pub ebgp_multihop: Option<i64>,
pub fabric: Option<String>,
pub isis_domain: Option<String>,
pub isis_ifaces: Option<String>,
pub isis_net: Option<String>,
pub lock_token: Option<String>,
pub loopback: Option<String>,
pub node: Option<String>,
pub nodes: Option<String>,
pub peer_group_name: Option<String>,
pub peers: Option<String>,
pub route_map_in: Option<String>,
pub route_map_out: Option<String>,
}Fields
asn: Option<i32>autonomous system number
bgp_mode: Option<PveBgpModeEnum>Whether to use eBGP or iBGP. Auto mode chooses depending on BGP controller or falls back to iBGP.
bgp_multipath_as_path_relax: Option<PveBoolean>Consider different AS paths of equal length for multipath computation.
delete: Option<String>A list of settings you want to delete.
digest: Option<String>Prevent changes if current configuration file has a different digest. This can be used to prevent concurrent modifications.
ebgp: Option<PveBoolean>Enable eBGP (remote-as external).
ebgp_multihop: Option<i64>Set maximum amount of hops for eBGP peers.
fabric: Option<String>SDN fabric to use as underlay for this EVPN controller.
isis_domain: Option<String>Name of the IS-IS domain.
isis_ifaces: Option<String>Comma-separated list of interfaces where IS-IS should be active.
isis_net: Option<String>Network Entity title for this node in the IS-IS network.
lock_token: Option<String>the token for unlocking the global SDN configuration
loopback: Option<String>Name of the loopback/dummy interface that provides the Router-IP.
node: Option<String>The cluster node name.
nodes: Option<String>List of cluster node names.
peer_group_name: Option<String>Name of the peer group for this EVPN controller
peers: Option<String>peers address list.
route_map_in: Option<String>Route Map that should be applied for incoming routes
route_map_out: Option<String>Route Map that should be applied for outgoing routes
Implementations