pub struct LxcCloneVmRequest {
pub bwlimit: Option<f64>,
pub description: Option<String>,
pub full: Option<PveBoolean>,
pub hostname: Option<String>,
pub newid: i32,
pub pool: Option<String>,
pub snapname: Option<String>,
pub storage: Option<String>,
pub target: Option<String>,
}Fields
bwlimit: Option<f64>Override I/O bandwidth limit (in KiB/s).
description: Option<String>Description for the new CT.
full: Option<PveBoolean>Create a full copy of all disks. This is always done when you clone a normal CT. For CT templates, we try to create a linked clone by default.
hostname: Option<String>Set a hostname for the new CT.
newid: i32VMID for the clone.
pool: Option<String>Add the new CT to the specified pool.
snapname: Option<String>The name of the snapshot.
storage: Option<String>Target storage for full clone.
target: Option<String>Target node. Only allowed if the original VM is on shared storage.
Implementations
Sourceimpl LxcCloneVmRequest
impl LxcCloneVmRequest
pub fn new(newid: i32) -> LxcCloneVmRequest