LxcSetOptionsRequest

Struct LxcSetOptionsRequest 

pub struct LxcSetOptionsRequest {
    pub delete: Option<String>,
    pub dhcp: Option<PveBoolean>,
    pub digest: Option<String>,
    pub enable: Option<PveBoolean>,
    pub ipfilter: Option<PveBoolean>,
    pub log_level_in: Option<PveLogEnum>,
    pub log_level_out: Option<PveLogEnum>,
    pub macfilter: Option<PveBoolean>,
    pub ndp: Option<PveBoolean>,
    pub policy_in: Option<PvePolicyInEnum>,
    pub policy_out: Option<PvePolicyInEnum>,
    pub radv: Option<PveBoolean>,
}

Fields

delete: Option<String>

A list of settings you want to delete.

dhcp: Option<PveBoolean>

Enable DHCP.

digest: Option<String>

Prevent changes if current configuration file has a different digest. This can be used to prevent concurrent modifications.

enable: Option<PveBoolean>

Enable/disable firewall rules.

ipfilter: Option<PveBoolean>

Enable default IP filters. This is equivalent to adding an empty ipfilter-net ipset for every interface. Such ipsets implicitly contain sane default restrictions such as restricting IPv6 link local addresses to the one derived from the interface’s MAC address. For containers the configured IP addresses will be implicitly added.

log_level_in: Option<PveLogEnum>

Log level for incoming traffic.

log_level_out: Option<PveLogEnum>

Log level for outgoing traffic.

macfilter: Option<PveBoolean>

Enable/disable MAC address filter.

ndp: Option<PveBoolean>

Enable NDP (Neighbor Discovery Protocol).

policy_in: Option<PvePolicyInEnum>

Input policy.

policy_out: Option<PvePolicyInEnum>

Output policy.

radv: Option<PveBoolean>

Allow sending Router Advertisement.

Implementations