pub struct LxcVmStatusResponseData {Show 24 fields
pub cpu: Option<f64>,
pub cpus: Option<f64>,
pub disk: Option<i64>,
pub diskread: Option<i64>,
pub diskwrite: Option<i64>,
pub ha: Value,
pub lock: Option<String>,
pub maxdisk: Option<i64>,
pub maxmem: Option<i64>,
pub maxswap: Option<i64>,
pub mem: Option<i64>,
pub name: Option<String>,
pub netin: Option<i64>,
pub netout: Option<i64>,
pub pressurecpusome: Option<f64>,
pub pressureiofull: Option<f64>,
pub pressureiosome: Option<f64>,
pub pressurememoryfull: Option<f64>,
pub pressurememorysome: Option<f64>,
pub status: PveStatusEnum,
pub tags: Option<String>,
pub template: Option<PveBoolean>,
pub uptime: Option<i64>,
pub vmid: i32,
}Fields
cpu: Option<f64>Current CPU usage.
cpus: Option<f64>Maximum usable CPUs.
disk: Option<i64>Root disk image space-usage in bytes.
diskread: Option<i64>The amount of bytes the guest read from it’s block devices since the guest was started. (Note: This info is not available for all storage types.)
diskwrite: Option<i64>The amount of bytes the guest wrote from it’s block devices since the guest was started. (Note: This info is not available for all storage types.)
ha: ValueHA manager service status.
lock: Option<String>The current config lock, if any.
maxdisk: Option<i64>Root disk image size in bytes.
maxmem: Option<i64>Maximum memory in bytes.
maxswap: Option<i64>Maximum SWAP memory in bytes.
mem: Option<i64>Currently used memory in bytes.
name: Option<String>Container name.
netin: Option<i64>The amount of traffic in bytes that was sent to the guest over the network since it was started.
netout: Option<i64>The amount of traffic in bytes that was sent from the guest over the network since it was started.
pressurecpusome: Option<f64>CPU Some pressure stall average over the last 10 seconds.
pressureiofull: Option<f64>IO Full pressure stall average over the last 10 seconds.
pressureiosome: Option<f64>IO Some pressure stall average over the last 10 seconds.
pressurememoryfull: Option<f64>Memory Full pressure stall average over the last 10 seconds.
pressurememorysome: Option<f64>Memory Some pressure stall average over the last 10 seconds.
status: PveStatusEnumLXC Container status.
The current configured tags, if any.
template: Option<PveBoolean>Determines if the guest is a template.
uptime: Option<i64>Uptime in seconds.
vmid: i32The (unique) ID of the VM.
Implementations
Sourceimpl LxcVmStatusResponseData
impl LxcVmStatusResponseData
pub fn new( ha: Value, status: PveStatusEnum, vmid: i32, ) -> LxcVmStatusResponseData