pub struct NodesCapabilitiesGetCpuResponseDataInner {
pub abstract: Option<PveBoolean>,
pub custom: PveBoolean,
pub name: String,
pub vendor: String,
}Fields
abstract: Option<PveBoolean>True for PVE-internal abstract profiles like x86-64-v2, -v3, -v4. These do not correspond to a QEMU CPU type and cannot be used as a custom model’s ‘reported-model’.
custom: PveBooleanTrue if this is a custom CPU model.
name: StringName of the CPU model. Identifies it for subsequent API calls. Prefixed with ‘custom-’ for custom models.
vendor: StringCPU vendor visible to the guest when this model is selected. Vendor of ‘reported-model’ in case of custom models.
Implementations
Sourceimpl NodesCapabilitiesGetCpuResponseDataInner
impl NodesCapabilitiesGetCpuResponseDataInner
pub fn new( custom: PveBoolean, name: String, vendor: String, ) -> NodesCapabilitiesGetCpuResponseDataInner