pub struct NodesCephCreateosdRequest {
pub crush_device_class: Option<String>,
pub db_dev: Option<String>,
pub db_dev_size: Option<f64>,
pub dev: String,
pub encrypted: Option<PveBoolean>,
pub osds_per_device: Option<i64>,
pub wal_dev: Option<String>,
pub wal_dev_size: Option<f64>,
}Fields
crush_device_class: Option<String>Set the device class of the OSD in crush.
db_dev: Option<String>Block device name for block.db.
db_dev_size: Option<f64>If a block.db is requested but the size is not given, will be automatically selected by: bluestore_block_db_size from the ceph database (osd or global section) or config (osd or global section) in that order. If this is not available, it will be sized 10% of the size of the OSD device. Fails if the available size is not enough.
dev: StringBlock device name.
encrypted: Option<PveBoolean>Enables encryption of the OSD.
osds_per_device: Option<i64>OSD services per physical device. Only useful for fast NVMe devices to utilize their performance better. Mutually exclusive with ‘db_dev’ and ‘wal_dev’.
wal_dev: Option<String>Block device name for block.wal.
wal_dev_size: Option<f64>If a block.wal is requested but the size is not given, will be automatically selected by: bluestore_block_wal_size from the ceph database (osd or global section) or config (osd or global section) in that order. If this is not available, it will be sized 1% of the size of the OSD device. Fails if the available size is not enough.
Implementations
Sourceimpl NodesCephCreateosdRequest
impl NodesCephCreateosdRequest
pub fn new(dev: String) -> NodesCephCreateosdRequest