pub struct NodesCephCreatepoolRequest {
pub add_storages: Option<PveBoolean>,
pub application: Option<PveApplicationEnum>,
pub crush_rule: Option<String>,
pub erasure_coding: Option<Box<PveErasureCodingField>>,
pub min_size: Option<i32>,
pub name: String,
pub pg_autoscale_mode: Option<PvePgAutoscaleModeEnum>,
pub pg_num: Option<i32>,
pub pg_num_min: Option<i32>,
pub size: Option<i32>,
pub target_size: Option<String>,
pub target_size_ratio: Option<f64>,
}Fields
add_storages: Option<PveBoolean>Configure VM and CT storage using the new pool. Defaults to false for replicated pools and to true for erasure-coded pools (since EC pools are typically only useful when wired up to storage).
application: Option<PveApplicationEnum>The application of the pool.
crush_rule: Option<String>The rule to use for mapping object placement in the cluster.
erasure_coding: Option<Box<PveErasureCodingField>>Create an erasure coded pool for RBD with an accompaning replicated pool for metadata storage. With EC, the common ceph options ‘size’, ‘min_size’ and ‘crush_rule’ parameters will be applied to the metadata pool.
min_size: Option<i32>Minimum number of replicas per object
name: StringThe name of the pool. It must be unique.
pg_autoscale_mode: Option<PvePgAutoscaleModeEnum>The automatic PG scaling mode of the pool.
pg_num: Option<i32>Number of placement groups.
pg_num_min: Option<i32>Minimal number of placement groups.
size: Option<i32>Number of replicas per object
target_size: Option<String>The estimated target size of the pool for the PG autoscaler.
target_size_ratio: Option<f64>The estimated target ratio of the pool for the PG autoscaler.
Implementations
Sourceimpl NodesCephCreatepoolRequest
impl NodesCephCreatepoolRequest
pub fn new(name: String) -> NodesCephCreatepoolRequest