pub struct NodesCephGetpoolResponseData {Show 24 fields
pub application: Option<PveApplicationEnum>,
pub application_list: Option<Vec<String>>,
pub autoscale_status: Option<Value>,
pub crush_rule: Option<String>,
pub fast_read: PveBoolean,
pub hashpspool: PveBoolean,
pub id: i64,
pub min_size: Option<i32>,
pub name: String,
pub nodeep_scrub: PveBoolean,
pub nodelete: PveBoolean,
pub nopgchange: PveBoolean,
pub noscrub: PveBoolean,
pub nosizechange: PveBoolean,
pub pg_autoscale_mode: Option<PvePgAutoscaleModeEnum>,
pub pg_num: Option<i32>,
pub pg_num_min: Option<i32>,
pub pgp_num: i64,
pub size: Option<i32>,
pub statistics: Option<Value>,
pub target_size: Option<String>,
pub target_size_ratio: Option<f64>,
pub use_gmt_hitset: PveBoolean,
pub write_fadvise_dontneed: PveBoolean,
}Fields
application: Option<PveApplicationEnum>The application of the pool.
application_list: Option<Vec<String>>Names of applications currently associated with the pool.
autoscale_status: Option<Value>Raw pg_autoscaler status object for this pool; shape varies between Ceph releases.
crush_rule: Option<String>The rule to use for mapping object placement in the cluster.
fast_read: PveBooleanSet if the pool uses fast-read for erasure-coded reads.
hashpspool: PveBooleanSet if the pool hashes pool id into its CRUSH placement-seed.
id: i64Numeric pool id assigned by Ceph.
min_size: Option<i32>Minimum number of replicas per object
name: StringThe name of the pool. It must be unique.
nodeep_scrub: PveBooleanSet if deep-scrubbing is disabled for this pool.
nodelete: PveBooleanSet if pool delete is blocked.
nopgchange: PveBooleanSet if changing the placement-group count is blocked.
noscrub: PveBooleanSet if scrubbing is disabled for this pool.
nosizechange: PveBooleanSet if changing the replication size is blocked.
pg_autoscale_mode: Option<PvePgAutoscaleModeEnum>The automatic PG scaling mode of the pool.
pg_num: Option<i32>Number of placement groups.
pg_num_min: Option<i32>Minimal number of placement groups.
pgp_num: i64Placement-group-for-placement count.
size: Option<i32>Number of replicas per object
statistics: Option<Value>Optional pool usage and IO statistics (only present when verbose=1 is requested).
target_size: Option<String>The estimated target size of the pool for the PG autoscaler.
target_size_ratio: Option<f64>The estimated target ratio of the pool for the PG autoscaler.
use_gmt_hitset: PveBooleanSet if hitsets use GMT timestamps (for cache-tier pools).
write_fadvise_dontneed: PveBooleanSet if the pool sets the FADV_DONTNEED hint on writes.
Implementations
Sourceimpl NodesCephGetpoolResponseData
impl NodesCephGetpoolResponseData
pub fn new( fast_read: PveBoolean, hashpspool: PveBoolean, id: i64, name: String, nodeep_scrub: PveBoolean, nodelete: PveBoolean, nopgchange: PveBoolean, noscrub: PveBoolean, nosizechange: PveBoolean, pgp_num: i64, use_gmt_hitset: PveBoolean, write_fadvise_dontneed: PveBoolean, ) -> NodesCephGetpoolResponseData