pub struct NodesConfigSetOptionsRequest {
pub acme: Option<Box<PveNodesConfigAcmeField>>,
pub ballooning_target: Option<i32>,
pub delete: Option<String>,
pub description: Option<String>,
pub digest: Option<String>,
pub location: Option<Box<PveLocationField>>,
pub startall_onboot_delay: Option<i32>,
pub wakeonlan: Option<Box<PveNodesConfigWakeonlanField>>,
pub acmedomains: Option<HashMap<u32, PveNodesConfigAcmedomainField>>,
}Fields
acme: Option<Box<PveNodesConfigAcmeField>>Node specific ACME settings.
ballooning_target: Option<i32>RAM usage target for ballooning (in percent of total memory)
delete: Option<String>A list of settings you want to delete.
description: Option<String>Description for the Node. Shown in the web-interface node notes panel. This is saved as comment inside the configuration file.
digest: Option<String>Prevent changes if current configuration file has different SHA1 digest. This can be used to prevent concurrent modifications.
location: Option<Box<PveLocationField>>The location of the node. Overrides the default from the datacenter config.
startall_onboot_delay: Option<i32>Initial delay in seconds, before starting all the Virtual Guests with on-boot enabled.
wakeonlan: Option<Box<PveNodesConfigWakeonlanField>>Node specific wake on LAN settings.
acmedomains: Option<HashMap<u32, PveNodesConfigAcmedomainField>>Acmedomains family. Wire form: acmedomain0..acmedomain8. Serialised by the manual impls below.
Implementations
Sourceimpl NodesConfigSetOptionsRequest
impl NodesConfigSetOptionsRequest
pub fn new() -> NodesConfigSetOptionsRequest