pub struct NodesStartallRequest {
pub force: Option<PveBoolean>,
pub max_workers: Option<i32>,
pub vms: Option<String>,
}Fields
force: Option<PveBoolean>Issue start command even if virtual guest have ‘onboot’ not set or set to off.
max_workers: Option<i32>Defines the maximum number of tasks running concurrently. If not set, uses ‘max_workers’ from datacenter.cfg, and if that’s not set, the available CPU threads, clamped to a maximum of 8, are used.
vms: Option<String>Only consider guests from this comma separated list of VMIDs.
Implementations
Sourceimpl NodesStartallRequest
impl NodesStartallRequest
pub fn new() -> NodesStartallRequest