Enums
- Access
Change Password Error - struct for typed errors of method
access_change_password - Access
GetAccess Error - struct for typed errors of method
access_get_access - Access
Permissions Error - struct for typed errors of method
access_permissions - Access
Verify VncTicket Error - struct for typed errors of method
access_verify_vnc_ticket
Functions
- access_
change_ password - Change user password. Permissions: Each user is allowed to change their own password. A user can change the password of another user if they have ‘Realm.AllocateUser’ (on the realm of user
) and ‘User.Modify’ permission on /access/groups/ on a group where user is member of. For the PAM realm, a password change does not take effect cluster-wide, but only applies to the local node. - access_
get_ access - Directory index.
- access_
permissions - Retrieve effective permissions of given user/token. Permissions: Each user/token is allowed to dump their own permissions (or that of owned tokens). A user can dump the permissions of another user or their tokens if they have ‘Sys.Audit’ permission on /access.
- access_
verify_ vnc_ ticket - verify VNC authentication ticket. Permissions: You need to pass valid credientials.