Enums
- Access
Users Create User Error - struct for typed errors of method
access_users_create_user - Access
Users Delete User Error - struct for typed errors of method
access_users_delete_user - Access
Users Generate Token Error - struct for typed errors of method
access_users_generate_token - Access
Users GetUsers Error - struct for typed errors of method
access_users_get_users - Access
Users Read Token Error - struct for typed errors of method
access_users_read_token - Access
Users Read User Error - struct for typed errors of method
access_users_read_user - Access
Users Read User TfaType Error - struct for typed errors of method
access_users_read_user_tfa_type - Access
Users Remove Token Error - struct for typed errors of method
access_users_remove_token - Access
Users Token Index Error - struct for typed errors of method
access_users_token_index - Access
Users Unlock TfaError - struct for typed errors of method
access_users_unlock_tfa - Access
Users Update Token Info Error - struct for typed errors of method
access_users_update_token_info - Access
Users Update User Error - struct for typed errors of method
access_users_update_user
Functions
- access_
users_ create_ user - Create new user. Permissions: You need ‘Realm.AllocateUser’ on ‘/access/realm/
’ on the realm of user , and ‘User.Modify’ permissions to ‘/access/groups/ ’ for any group specified (or ‘User.Modify’ on ‘/access/groups’ if you pass no groups. - access_
users_ delete_ user - Delete user.
- access_
users_ generate_ token - Generate a new API token for a specific user. NOTE: returns API token value, which needs to be stored as it cannot be retrieved afterwards!
- access_
users_ get_ users - User index. Permissions: The returned list is restricted to users where you have ‘User.Modify’ or ‘Sys.Audit’ permissions on ‘/access/groups’ or on a group the user belongs too. But it always includes the current (authenticated) user.
- access_
users_ read_ token - Get specific API token information.
- access_
users_ read_ user - Get user configuration.
- access_
users_ read_ user_ tfa_ type - Get user TFA types (Personal and Realm).
- access_
users_ remove_ token - Remove API token for a specific user.
- access_
users_ token_ index - Get user API tokens.
- access_
users_ unlock_ tfa - Unlock a user’s TFA authentication.
- access_
users_ update_ token_ info - Update API token for a specific user. NOTE: when ‘regenerate’ is set, the returned token value needs to be stored as it cannot be retrieved afterwards!
- access_
users_ update_ user - Update user configuration.