Enums
- Cluster
Notifications Create Gotify Endpoint Error - struct for typed errors of method
cluster_notifications_create_gotify_endpoint - Cluster
Notifications Create Matcher Error - struct for typed errors of method
cluster_notifications_create_matcher - Cluster
Notifications Create Sendmail Endpoint Error - struct for typed errors of method
cluster_notifications_create_sendmail_endpoint - Cluster
Notifications Create Smtp Endpoint Error - struct for typed errors of method
cluster_notifications_create_smtp_endpoint - Cluster
Notifications Create Webhook Endpoint Error - struct for typed errors of method
cluster_notifications_create_webhook_endpoint - Cluster
Notifications Delete Gotify Endpoint Error - struct for typed errors of method
cluster_notifications_delete_gotify_endpoint - Cluster
Notifications Delete Matcher Error - struct for typed errors of method
cluster_notifications_delete_matcher - Cluster
Notifications Delete Sendmail Endpoint Error - struct for typed errors of method
cluster_notifications_delete_sendmail_endpoint - Cluster
Notifications Delete Smtp Endpoint Error - struct for typed errors of method
cluster_notifications_delete_smtp_endpoint - Cluster
Notifications Delete Webhook Endpoint Error - struct for typed errors of method
cluster_notifications_delete_webhook_endpoint - Cluster
Notifications Endpoints Index Error - struct for typed errors of method
cluster_notifications_endpoints_index - Cluster
Notifications GetAll Targets Error - struct for typed errors of method
cluster_notifications_get_all_targets - Cluster
Notifications GetGotify Endpoint Error - struct for typed errors of method
cluster_notifications_get_gotify_endpoint - Cluster
Notifications GetGotify Endpoints Error - struct for typed errors of method
cluster_notifications_get_gotify_endpoints - Cluster
Notifications GetMatcher Error - struct for typed errors of method
cluster_notifications_get_matcher - Cluster
Notifications GetMatcher Field Values Error - struct for typed errors of method
cluster_notifications_get_matcher_field_values - Cluster
Notifications GetMatcher Fields Error - struct for typed errors of method
cluster_notifications_get_matcher_fields - Cluster
Notifications GetMatchers Error - struct for typed errors of method
cluster_notifications_get_matchers - Cluster
Notifications GetNotifications Error - struct for typed errors of method
cluster_notifications_get_notifications - Cluster
Notifications GetSendmail Endpoint Error - struct for typed errors of method
cluster_notifications_get_sendmail_endpoint - Cluster
Notifications GetSendmail Endpoints Error - struct for typed errors of method
cluster_notifications_get_sendmail_endpoints - Cluster
Notifications GetSmtp Endpoint Error - struct for typed errors of method
cluster_notifications_get_smtp_endpoint - Cluster
Notifications GetSmtp Endpoints Error - struct for typed errors of method
cluster_notifications_get_smtp_endpoints - Cluster
Notifications GetWebhook Endpoint Error - struct for typed errors of method
cluster_notifications_get_webhook_endpoint - Cluster
Notifications GetWebhook Endpoints Error - struct for typed errors of method
cluster_notifications_get_webhook_endpoints - Cluster
Notifications Test Target Error - struct for typed errors of method
cluster_notifications_test_target - Cluster
Notifications Update Gotify Endpoint Error - struct for typed errors of method
cluster_notifications_update_gotify_endpoint - Cluster
Notifications Update Matcher Error - struct for typed errors of method
cluster_notifications_update_matcher - Cluster
Notifications Update Sendmail Endpoint Error - struct for typed errors of method
cluster_notifications_update_sendmail_endpoint - Cluster
Notifications Update Smtp Endpoint Error - struct for typed errors of method
cluster_notifications_update_smtp_endpoint - Cluster
Notifications Update Webhook Endpoint Error - struct for typed errors of method
cluster_notifications_update_webhook_endpoint
Functions
- cluster_
notifications_ create_ gotify_ endpoint - Create a new gotify endpoint
- cluster_
notifications_ create_ matcher - Create a new matcher
- cluster_
notifications_ create_ sendmail_ endpoint - Create a new sendmail endpoint
- cluster_
notifications_ create_ smtp_ endpoint - Create a new smtp endpoint
- cluster_
notifications_ create_ webhook_ endpoint - Create a new webhook endpoint
- cluster_
notifications_ delete_ gotify_ endpoint - Remove gotify endpoint
- cluster_
notifications_ delete_ matcher - Remove matcher
- cluster_
notifications_ delete_ sendmail_ endpoint - Remove sendmail endpoint
- cluster_
notifications_ delete_ smtp_ endpoint - Remove smtp endpoint
- cluster_
notifications_ delete_ webhook_ endpoint - Remove webhook endpoint
- cluster_
notifications_ endpoints_ index - Index for all available endpoint types.
- cluster_
notifications_ get_ all_ targets - Returns a list of all entities that can be used as notification targets.
- cluster_
notifications_ get_ gotify_ endpoint - Return a specific gotify endpoint
- cluster_
notifications_ get_ gotify_ endpoints - Returns a list of all gotify endpoints
- cluster_
notifications_ get_ matcher - Return a specific matcher
- cluster_
notifications_ get_ matcher_ field_ values - Returns known notification metadata fields and their known values
- cluster_
notifications_ get_ matcher_ fields - Returns known notification metadata fields
- cluster_
notifications_ get_ matchers - Returns a list of all matchers
- cluster_
notifications_ get_ notifications - Index for notification-related API endpoints.
- cluster_
notifications_ get_ sendmail_ endpoint - Return a specific sendmail endpoint
- cluster_
notifications_ get_ sendmail_ endpoints - Returns a list of all sendmail endpoints
- cluster_
notifications_ get_ smtp_ endpoint - Return a specific smtp endpoint
- cluster_
notifications_ get_ smtp_ endpoints - Returns a list of all smtp endpoints
- cluster_
notifications_ get_ webhook_ endpoint - Return a specific webhook endpoint
- cluster_
notifications_ get_ webhook_ endpoints - Returns a list of all webhook endpoints
- cluster_
notifications_ test_ target - Send a test notification to a provided target.
- cluster_
notifications_ update_ gotify_ endpoint - Update existing gotify endpoint
- cluster_
notifications_ update_ matcher - Update existing matcher
- cluster_
notifications_ update_ sendmail_ endpoint - Update existing sendmail endpoint
- cluster_
notifications_ update_ smtp_ endpoint - Update existing smtp endpoint
- cluster_
notifications_ update_ webhook_ endpoint - Update existing webhook endpoint