Enums
- Nodes
Storage Copy Error - struct for typed errors of method
nodes_storage_copy - Nodes
Storage Create Content Error - struct for typed errors of method
nodes_storage_create_content - Nodes
Storage Delete Content Error - struct for typed errors of method
nodes_storage_delete_content - Nodes
Storage Delete Prunebackups Error - struct for typed errors of method
nodes_storage_delete_prunebackups - Nodes
Storage Diridx Error - struct for typed errors of method
nodes_storage_diridx - Nodes
Storage Download Error - struct for typed errors of method
nodes_storage_download - Nodes
Storage Download UrlError - struct for typed errors of method
nodes_storage_download_url - Nodes
Storage Dryrun Error - struct for typed errors of method
nodes_storage_dryrun - Nodes
Storage GetContent Error - struct for typed errors of method
nodes_storage_get_content - Nodes
Storage GetImport Metadata Error - struct for typed errors of method
nodes_storage_get_import_metadata - Nodes
Storage GetList Error - struct for typed errors of method
nodes_storage_get_list - Nodes
Storage GetStorage Error - struct for typed errors of method
nodes_storage_get_storage - Nodes
Storage Identity Error - struct for typed errors of method
nodes_storage_identity - Nodes
Storage Info Error - struct for typed errors of method
nodes_storage_info - Nodes
Storage OciRegistry Pull Error - struct for typed errors of method
nodes_storage_oci_registry_pull - Nodes
Storage Read Status Error - struct for typed errors of method
nodes_storage_read_status - Nodes
Storage RrdError - struct for typed errors of method
nodes_storage_rrd - Nodes
Storage Rrddata Error - struct for typed errors of method
nodes_storage_rrddata - Nodes
Storage Updateattributes Error - struct for typed errors of method
nodes_storage_updateattributes - Nodes
Storage Upload Error - struct for typed errors of method
nodes_storage_upload
Functions
- nodes_
storage_ copy - Copy a volume. This is experimental code - do not use.
- nodes_
storage_ create_ content - Allocate disk images.
- nodes_
storage_ delete_ content - Delete volume Permissions: You need ‘Datastore.Allocate’ privilege on the storage (or ‘Datastore.AllocateSpace’ for backup volumes if you have VM.Backup privilege on the VM).
- nodes_
storage_ delete_ prunebackups - Prune backups. Only those using the standard naming scheme are considered. Permissions: You need the ‘Datastore.Allocate’ privilege on the storage (or if a VM ID is specified, ‘Datastore.AllocateSpace’ and ‘VM.Backup’ for the VM).
- nodes_
storage_ diridx - nodes_
storage_ download - Extract a file or directory (as zip archive) from a PBS backup. Permissions: You need read access for the volume.
- nodes_
storage_ download_ url - Download templates, ISO images, OVAs and VM images by using an URL. Permissions: Requires allocation access on the storage and as this allows one to probe the (local!) host network indirectly it also requires one of Sys.Modify on / (for backwards compatibility) or the newer Sys.AccessNetwork privilege on the node.
- nodes_
storage_ dryrun - Get prune information for backups. NOTE: this is only a preview and might not be what a subsequent prune call does if backups are removed/added in the meantime.
- nodes_
storage_ get_ content - List storage content.
- nodes_
storage_ get_ import_ metadata - Get the base parameters for creating a guest which imports data from a foreign importable guest, like an ESXi VM Permissions: You need read access for the volume.
- nodes_
storage_ get_ list - List files and directories for single file restore under the given path. Permissions: You need read access for the volume.
- nodes_
storage_ get_ storage - Get status for all datastores. Permissions: Only list entries where you have ‘Datastore.Audit’ or ‘Datastore.AllocateSpace’ permissions on ‘/storage/
’ - nodes_
storage_ identity - Return identity information for this storage instance.
- nodes_
storage_ info - Get volume attributes Permissions: You need read access for the volume.
- nodes_
storage_ oci_ registry_ pull - Pull an OCI image from a registry.
- nodes_
storage_ read_ status - Read storage status.
- nodes_
storage_ rrd - Read storage RRD statistics (returns PNG).
- nodes_
storage_ rrddata - Read storage RRD statistics.
- nodes_
storage_ updateattributes - Update volume attributes Permissions: You need read access for the volume.
- nodes_
storage_ upload - Upload templates, ISO images, OVAs and VM images.