Enums
- Nodes
Tasks Node Tasks Error - struct for typed errors of method
nodes_tasks_node_tasks - Nodes
Tasks Read Task LogError - struct for typed errors of method
nodes_tasks_read_task_log - Nodes
Tasks Read Task Status Error - struct for typed errors of method
nodes_tasks_read_task_status - Nodes
Tasks Stop Task Error - struct for typed errors of method
nodes_tasks_stop_task - Nodes
Tasks Upid Index Error - struct for typed errors of method
nodes_tasks_upid_index
Functions
- nodes_
tasks_ node_ tasks - Read task list for one node (finished tasks). Permissions: List task associated with the current user, or all task the user has ‘Sys.Audit’ permissions on /nodes/
(the the task runs on). - nodes_
tasks_ read_ task_ log - Read task log. Permissions: The user needs ‘Sys.Audit’ permissions on ‘/nodes/
’ if they aren’t the owner of the task. - nodes_
tasks_ read_ task_ status - Read task status. Permissions: The user needs ‘Sys.Audit’ permissions on ‘/nodes/
’ if they are not the owner of the task. - nodes_
tasks_ stop_ task - Stop a task. Permissions: The user needs ‘Sys.Modify’ permissions on ‘/nodes/
’ if they aren’t the owner of the task. - nodes_
tasks_ upid_ index