pub struct AccessDomainsSyncRequest {
pub dry_run: Option<PveBoolean>,
pub enable_new: PveBoolean,
pub full: PveBoolean,
pub purge: PveBoolean,
pub remove_vanished: String,
pub scope: PveScopeEnum,
}Fields
dry_run: Option<PveBoolean>If set, does not write anything.
enable_new: PveBooleanEnable newly synced users immediately.
full: PveBooleanDEPRECATED: use ‘remove-vanished’ instead. If set, uses the LDAP Directory as source of truth, deleting users or groups not returned from the sync and removing all locally modified properties of synced users. If not set, only syncs information which is present in the synced data, and does not delete or modify anything else.
purge: PveBooleanDEPRECATED: use ‘remove-vanished’ instead. Remove ACLs for users or groups which were removed from the config during a sync.
remove_vanished: StringA semicolon-separated list of things to remove when they or the user vanishes during a sync. The following values are possible: ‘entry’ removes the user/group when not returned from the sync. ‘properties’ removes the set properties on existing user/group that do not appear in the source (even custom ones). ‘acl’ removes acls when the user/group is not returned from the sync. Instead of a list it also can be ‘none’ (the default).
scope: PveScopeEnumSelect what to sync.
Implementations
Sourceimpl AccessDomainsSyncRequest
impl AccessDomainsSyncRequest
pub fn new( enable_new: PveBoolean, full: PveBoolean, purge: PveBoolean, remove_vanished: String, scope: PveScopeEnum, ) -> AccessDomainsSyncRequest