pub struct ClusterHaUpdateRuleRequest {
pub affinity: Option<PveAffinityEnum>,
pub comment: Option<String>,
pub delete: Option<String>,
pub digest: Option<String>,
pub disable: Option<PveBoolean>,
pub nodes: Option<String>,
pub resources: Option<String>,
pub strict: Option<PveBoolean>,
pub type: PveCauseEnum,
}Fields
affinity: Option<PveAffinityEnum>Describes whether the HA resources are supposed to be kept on the same node (‘positive’), or are supposed to be kept on separate nodes (‘negative’).
comment: Option<String>HA rule description.
delete: Option<String>A list of settings you want to delete.
digest: Option<String>Prevent changes if current configuration file has a different digest. This can be used to prevent concurrent modifications.
disable: Option<PveBoolean>Whether the HA rule is disabled.
nodes: Option<String>List of cluster node members, where a priority can be given to each node. A resource will run on the available nodes with the highest priority. If there are more nodes in the highest priority class, the resources will get distributed to those nodes. The priorities have a relative meaning only. The higher the number, the higher the priority.
resources: Option<String>List of HA resource IDs. This consists of a list of resource types followed by a resource specific name separated with a colon (example: vm:100,ct:101).
strict: Option<PveBoolean>Describes whether the node affinity rule is strict or non-strict. A non-strict node affinity rule makes resources prefer to be on the defined nodes. If none of the defined nodes are available, the resource may run on any other node. A strict node affinity rule makes resources be restricted to the defined nodes. If none of the defined nodes are available, the resource will be stopped.
type: PveCauseEnumHA rule type.
Implementations
Sourceimpl ClusterHaUpdateRuleRequest
impl ClusterHaUpdateRuleRequest
pub fn new(type: PveCauseEnum) -> ClusterHaUpdateRuleRequest