pub struct PveIdeConfig {Show 45 fields
pub aio: Option<PveAioEnum>,
pub backup: Option<PveBoolean>,
pub bps: Option<i64>,
pub bps_max_length: Option<i64>,
pub bps_rd: Option<i64>,
pub bps_rd_length: Option<String>,
pub bps_rd_max_length: Option<i64>,
pub bps_wr: Option<i64>,
pub bps_wr_length: Option<String>,
pub bps_wr_max_length: Option<i64>,
pub cache: Option<PveCacheEnum>,
pub detect_zeroes: Option<PveBoolean>,
pub discard: Option<PveDiscardEnum>,
pub file: String,
pub format: Option<PveFormatEnum>,
pub import_from: Option<String>,
pub iops: Option<i64>,
pub iops_max: Option<i64>,
pub iops_max_length: Option<i64>,
pub iops_rd: Option<i64>,
pub iops_rd_length: Option<String>,
pub iops_rd_max: Option<i64>,
pub iops_rd_max_length: Option<i64>,
pub iops_wr: Option<i64>,
pub iops_wr_length: Option<String>,
pub iops_wr_max: Option<i64>,
pub iops_wr_max_length: Option<i64>,
pub mbps: Option<f64>,
pub mbps_max: Option<f64>,
pub mbps_rd: Option<f64>,
pub mbps_rd_max: Option<f64>,
pub mbps_wr: Option<f64>,
pub mbps_wr_max: Option<f64>,
pub media: Option<PveMediaEnum>,
pub model: Option<String>,
pub replicate: Option<PveBoolean>,
pub rerror: Option<PveRerrorEnum>,
pub serial: Option<String>,
pub shared: Option<PveBoolean>,
pub size: Option<String>,
pub snapshot: Option<PveBoolean>,
pub ssd: Option<PveBoolean>,
pub volume: Option<String>,
pub werror: Option<PveWerrorEnum>,
pub wwn: Option<String>,
}Fields
aio: Option<PveAioEnum>AIO type to use.
backup: Option<PveBoolean>Whether the drive should be included when making backups.
bps: Option<i64>Maximum r/w speed in bytes per second.
bps_max_length: Option<i64>Maximum length of I/O bursts in seconds.
bps_rd: Option<i64>Maximum read speed in bytes per second.
bps_rd_length: Option<String>bps_rd_max_length: Option<i64>Maximum length of read I/O bursts in seconds.
bps_wr: Option<i64>Maximum write speed in bytes per second.
bps_wr_length: Option<String>bps_wr_max_length: Option<i64>Maximum length of write I/O bursts in seconds.
cache: Option<PveCacheEnum>The drive’s cache mode
detect_zeroes: Option<PveBoolean>Controls whether to detect and try to optimize writes of zeroes.
discard: Option<PveDiscardEnum>Controls whether to pass discard/trim requests to the underlying storage.
file: StringThe drive’s backing volume.
format: Option<PveFormatEnum>The drive’s backing file’s data format.
import_from: Option<String>Create a new disk, importing from this source (volume ID or absolute path). When an absolute path is specified, it’s up to you to ensure that the source is not actively used by another process during the import!
iops: Option<i64>Maximum r/w I/O in operations per second.
iops_max: Option<i64>Maximum unthrottled r/w I/O pool in operations per second.
iops_max_length: Option<i64>Maximum length of I/O bursts in seconds.
iops_rd: Option<i64>Maximum read I/O in operations per second.
iops_rd_length: Option<String>iops_rd_max: Option<i64>Maximum unthrottled read I/O pool in operations per second.
iops_rd_max_length: Option<i64>Maximum length of read I/O bursts in seconds.
iops_wr: Option<i64>Maximum write I/O in operations per second.
iops_wr_length: Option<String>iops_wr_max: Option<i64>Maximum unthrottled write I/O pool in operations per second.
iops_wr_max_length: Option<i64>Maximum length of write I/O bursts in seconds.
mbps: Option<f64>Maximum r/w speed in megabytes per second.
mbps_max: Option<f64>Maximum unthrottled r/w pool in megabytes per second.
mbps_rd: Option<f64>Maximum read speed in megabytes per second.
mbps_rd_max: Option<f64>Maximum unthrottled read pool in megabytes per second.
mbps_wr: Option<f64>Maximum write speed in megabytes per second.
mbps_wr_max: Option<f64>Maximum unthrottled write pool in megabytes per second.
media: Option<PveMediaEnum>The drive’s media type.
model: Option<String>The drive’s reported model name, url-encoded, up to 40 bytes long.
replicate: Option<PveBoolean>Whether the drive should considered for replication jobs.
rerror: Option<PveRerrorEnum>Read error action.
serial: Option<String>The drive’s reported serial number, url-encoded, up to 20 bytes long.
Mark this locally-managed volume as available on all nodes. WARNING: This option does not share the volume automatically, it assumes it is shared already!
size: Option<String>Disk size. This is purely informational and has no effect.
snapshot: Option<PveBoolean>Controls qemu’s snapshot mode feature. If activated, changes made to the disk are temporary and will be discarded when the VM is shutdown.
ssd: Option<PveBoolean>Whether to expose this drive as an SSD, rather than a rotational hard disk.
volume: Option<String>werror: Option<PveWerrorEnum>Write error action.
wwn: Option<String>The drive’s worldwide name, encoded as 16 bytes hex string, prefixed by ‘0x’.
Implementations
Sourceimpl PveIdeConfig
impl PveIdeConfig
pub fn new(file: String) -> PveIdeConfig
Sourceimpl PveIdeConfig
impl PveIdeConfig
Sourcepub fn to_shorthand(&self) -> String
pub fn to_shorthand(&self) -> String
Serialise this PveIdeConfig into Proxmox’s CLI-style shorthand
string (key=value,…). The property marked x-pve-default-key
is emitted positionally without a key= prefix; aliases collapse
multiple property names to the same wire key.
Example: PveIdeConfig
→ "virtio,bridge=vmbr0"