pub struct PveStorageDirConfig {Show 17 fields
pub path: String,
pub content_dirs: Option<String>,
pub nodes: Option<String>,
pub shared: Option<PveBoolean>,
pub disable: Option<PveBoolean>,
pub prune_backups: Option<String>,
pub max_protected_backups: Option<i64>,
pub content: Option<String>,
pub format: Option<PveFormatFormatEnum>,
pub mkdir: Option<PveBoolean>,
pub create_base_path: Option<PveBoolean>,
pub create_subdirs: Option<PveBoolean>,
pub is_mountpoint: Option<String>,
pub bwlimit: Option<Box<PveBwlimitField>>,
pub preallocation: Option<PvePreallocationEnum>,
pub snapshot_as_volume_chain: Option<PveBoolean>,
pub type: Type,
}Fields
path: StringFile system path.
content_dirs: Option<String>Overrides for default content type directories.
nodes: Option<String>List of nodes for which the storage configuration applies.
Indicate that this is a single storage with the same contents on all nodes (or all listed in the ‘nodes’ option). It will not make the contents of a local storage automatically accessible to other nodes, it just marks an already shared storage as such!
disable: Option<PveBoolean>Flag to disable the storage.
prune_backups: Option<String>The retention options with shorter intervals are processed first with –keep-last being the very first one. Each option covers a specific period of time. We say that backups within this period are covered by this option. The next option does not take care of already covered backups and only considers older backups.
max_protected_backups: Option<i64>Maximal number of protected backups per guest. Use ‘-1’ for unlimited.
content: Option<String>Allowed content types. NOTE: the value ‘rootdir’ is used for Containers, and value ‘images’ for VMs.
format: Option<PveFormatFormatEnum>Default image format.
mkdir: Option<PveBoolean>Create the directory if it doesn’t exist and populate it with default sub-dirs. NOTE: Deprecated, use the ‘create-base-path’ and ‘create-subdirs’ options instead.
create_base_path: Option<PveBoolean>Create the base directory if it doesn’t exist.
create_subdirs: Option<PveBoolean>Populate the directory with the default structure.
is_mountpoint: Option<String>Assume the given path is an externally managed mountpoint and consider the storage offline if it is not mounted. Using a boolean (yes/no) value serves as a shortcut to using the target path in this field.
bwlimit: Option<Box<PveBwlimitField>>Set I/O bandwidth limit for various operations (in KiB/s).
preallocation: Option<PvePreallocationEnum>Preallocation mode for raw and qcow2 images. Using ‘metadata’ on raw images results in preallocation=off.
snapshot_as_volume_chain: Option<PveBoolean>Enable support for creating storage-vendor agnostic snapshot through volume backing-chains.
type: TypeImplementations
Sourceimpl PveStorageDirConfig
impl PveStorageDirConfig
pub fn new(path: String, type: Type) -> PveStorageDirConfig